==> neoepiscope-0.3.9.tar.gz: neoepiscope-0.3.9/neoepiscope/paths.py <==
#!/usr/bin/env python
# coding=utf-8
"""
paths.py

Part of neoepiscope
Defines default paths of neoepiscope's dependencies.
None indicates the user didn't install the tool or data.

Licensed under the MIT license.

The MIT License (MIT)
Copyright (c) 2018 Mary A. Wood, Austin Nguyen,
                   Abhinav Nellore, and Reid Thompson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""
gencode_v29 = None
gencode_v19 = None
gencode_vM1 = None
bowtie_grch38 = None
bowtie_hg19 = None
bowtie_v37 = None
netMHCIIpan3 = None
netMHCpan3 = None
netMHCpan4 = None
netMHC4 = None
netMHCII2 = None
PickPocket1 = None
netMHCstabpan1 = None
PSSMHCpan1 = None
hapcut2_hairs = None
hapcut2 = None

==> neoepiscope-0.4.1.tar.gz: neoepiscope-0.4.1/neoepiscope/paths.py <==
#!/usr/bin/env python
# coding=utf-8
"""
paths.py

Part of neoepiscope
Defines default paths of neoepiscope's dependencies.
None indicates the user didn't install the tool or data.

Licensed under the MIT license.

The MIT License (MIT)
Copyright (c) 2018 Mary A. Wood, Austin Nguyen,
                   Abhinav Nellore, and Reid Thompson

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""
gencode_v29 = None
gencode_v19 = None
gencode_vM25 = None
gencode_vM1 = None
bowtie_grch38 = None
bowtie_hg19 = None
bowtie_mm10 = None
bowtie_mm9 = None
netMHCIIpan3 = None
netMHCIIpan4 = None
netMHCpan3 = None
netMHCpan4 = None
netMHCpan4_1 = None
netMHC4 = None
netMHCII2 = None
PickPocket1 = None
netMHCstabpan1 = None
PSSMHCpan1 = None
hapcut2_hairs = None
hapcut2 = None
